R/ViewR.R
install_viewr_deps.Rd
Checks which required packages are missing from the user's library and installs them via install.packages.
install.packages
install_viewr_deps(ask = TRUE)
Logical. If TRUE (default), prompt before installing.
TRUE
Invisibly returns a character vector of packages that were (or needed to be) installed.
if (FALSE) { # \dontrun{ install_viewr_deps() } # }